pub struct ApigatewayApi {
pub create_time: Option<DateTime<Utc>>,
pub display_name: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub managed_service: Option<String>,
pub name: Option<String>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
An API that can be served by one or more Gateways.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations apis create projects (request)
- locations apis get projects (response)
- locations apis patch projects (request)
Fields
create_time: Option<DateTime<Utc>>Output only. Created time.
display_name: Option<String>Optional. Display name.
labels: Option<HashMap<String, String>>Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/docs/labeling-resources
managed_service: Option<String>Optional. Immutable. The name of a Google Managed Service ( https://cloud.google.com/service-infrastructure/docs/glossary#managed). If not specified, a new Service will automatically be created in the same project as this API.
name: Option<String>Output only. Resource name of the API. Format: projects/{project}/locations/global/apis/{api}
state: Option<String>Output only. State of the API.
update_time: Option<DateTime<Utc>>Output only. Updated time.