ApigatewayApiConfig

Struct ApigatewayApiConfig 

pub struct ApigatewayApiConfig {
    pub create_time: Option<DateTime<Utc>>,
    pub display_name: Option<String>,
    pub gateway_service_account: Option<String>,
    pub grpc_services: Option<Vec<ApigatewayApiConfigGrpcServiceDefinition>>,
    pub labels: Option<HashMap<String, String>>,
    pub managed_service_configs: Option<Vec<ApigatewayApiConfigFile>>,
    pub name: Option<String>,
    pub openapi_documents: Option<Vec<ApigatewayApiConfigOpenApiDocument>>,
    pub service_config_id: Option<String>,
    pub state: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
}
An API Configuration is a combination of settings for both the Managed Service and Gateways serving this API Config.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<DateTime<Utc>>

Output only. Created time.

display_name: Option<String>

Optional. Display name.

gateway_service_account: Option<String>

Immutable. The Google Cloud IAM Service Account that Gateways serving this config should use to authenticate to other services. This may either be the Service Account’s email ({ACCOUNT_ID}@{PROJECT}.iam.gserviceaccount.com) or its full resource name (projects/{PROJECT}/accounts/{UNIQUE_ID}). This is most often used when the service is a GCP resource such as a Cloud Run Service or an IAP-secured service.

grpc_services: Option<Vec<ApigatewayApiConfigGrpcServiceDefinition>>

Optional. gRPC service definition files. If specified, openapi_documents must not be included.

labels: Option<HashMap<String, String>>

Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/docs/labeling-resources

managed_service_configs: Option<Vec<ApigatewayApiConfigFile>>

Optional. Service Configuration files. At least one must be included when using gRPC service definitions. See https://cloud.google.com/endpoints/docs/grpc/grpc-service-config#service_configuration_overview for the expected file contents. If multiple files are specified, the files are merged with the following rules: * All singular scalar fields are merged using “last one wins” semantics in the order of the files uploaded. * Repeated fields are concatenated. * Singular embedded messages are merged using these rules for nested fields.

name: Option<String>

Output only. Resource name of the API Config. Format: projects/{project}/locations/global/apis/{api}/configs/{api_config}

openapi_documents: Option<Vec<ApigatewayApiConfigOpenApiDocument>>

Optional. OpenAPI specification documents. If specified, grpc_services and managed_service_configs must not be included.

service_config_id: Option<String>

Output only. The ID of the associated Service Config ( https://cloud.google.com/service-infrastructure/docs/glossary#config).

state: Option<String>

Output only. State of the API Config.

update_time: Option<DateTime<Utc>>

Output only. Updated time.