pub struct ApigatewayApiConfigGrpcServiceDefinition {
pub file_descriptor_set: Option<ApigatewayApiConfigFile>,
pub source: Option<Vec<ApigatewayApiConfigFile>>,
}Expand description
A gRPC service definition.
This type is not used in any activity, and only used as part of another schema.
Fields
file_descriptor_set: Option<ApigatewayApiConfigFile>Input only. File descriptor set, generated by protoc. To generate, use protoc with imports and source info included. For an example test.proto file, the following command would put the value in a new file named out.pb. $ protoc –include_imports –include_source_info test.proto -o out.pb
source: Option<Vec<ApigatewayApiConfigFile>>Optional. Uncompiled proto files associated with the descriptor set, used for display purposes (server-side compilation is not supported). These should match the inputs to ‘protoc’ command used to generate file_descriptor_set.