pub struct ApigatewayAuditLogConfig {
pub exempted_members: Option<Vec<String>>,
pub log_type: Option<String>,
}Expand description
Provides the configuration for logging a type of permissions. Example: { “audit_log_configs”: [ { “log_type”: “DATA_READ”, “exempted_members”: [ “user:jose@example.com” ] }, { “log_type”: “DATA_WRITE” } ] } This enables ‘DATA_READ’ and ‘DATA_WRITE’ logging, while exempting jose@example.com from DATA_READ logging.
This type is not used in any activity, and only used as part of another schema.
Fields
exempted_members: Option<Vec<String>>Specifies the identities that do not cause logging for this type of permission. Follows the same format of Binding.members.
log_type: Option<String>The log type that this config enables.