pub struct ApigatewayGateway {
pub api_config: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub default_hostname: Option<String>,
pub display_name: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A Gateway is an API-aware HTTP proxy. It performs API-Method and/or API-Consumer specific actions based on an API Config such as authentication, policy enforcement, and backend selection.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations gateways create projects (request)
- locations gateways get projects (response)
- locations gateways patch projects (request)
Fields
api_config: Option<String>Required. Resource name of the API Config for this Gateway. Format: projects/{project}/locations/global/apis/{api}/configs/{apiConfig}
create_time: Option<DateTime<Utc>>Output only. Created time.
default_hostname: Option<String>Output only. The default API Gateway host name of the form {gateway_id}-{hash}.{region_code}.gateway.dev.
display_name: Option<String>Optional. Display name.
labels: Option<HashMap<String, String>>Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/docs/labeling-resources
name: Option<String>Output only. Resource name of the Gateway. Format: projects/{project}/locations/{location}/gateways/{gateway}
state: Option<String>Output only. The current state of the Gateway.
update_time: Option<DateTime<Utc>>Output only. Updated time.