pub struct ApigatewayListApiConfigsResponse {
pub api_configs: Option<Vec<ApigatewayApiConfig>>,
pub next_page_token: Option<String>,
pub unreachable_locations: Option<Vec<String>>,
}Expand description
Response message for ApiGatewayService.ListApiConfigs
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations apis configs list projects (response)
Fields
api_configs: Option<Vec<ApigatewayApiConfig>>API Configs.
next_page_token: Option<String>Next page token.
unreachable_locations: Option<Vec<String>>Locations that could not be reached.