pub struct ApigatewayListApisResponse {
pub apis: Option<Vec<ApigatewayApi>>,
pub next_page_token: Option<String>,
pub unreachable_locations: Option<Vec<String>>,
}Expand description
Response message for ApiGatewayService.ListApis
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations apis list projects (response)
Fields
apis: Option<Vec<ApigatewayApi>>APIs.
next_page_token: Option<String>Next page token.
unreachable_locations: Option<Vec<String>>Locations that could not be reached.