pub struct ApigatewayListLocationsResponse {
pub locations: Option<Vec<ApigatewayLocation>>,
pub next_page_token: Option<String>,
}Expand description
The response message for Locations.ListLocations.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations list projects (response)
Fields
locations: Option<Vec<ApigatewayLocation>>A list of locations that matches the specified filter in the request.
next_page_token: Option<String>The standard List next-page token.