pub struct ApigatewayListOperationsResponse {
pub next_page_token: Option<String>,
pub operations: Option<Vec<ApigatewayOperation>>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message for Operations.ListOperations.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations operations list projects (response)
Fields
next_page_token: Option<String>The standard List next-page token.
operations: Option<Vec<ApigatewayOperation>>A list of operations that matches the specified filter in the request.
unreachable: Option<Vec<String>>Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations.