pub struct ApigatewayLocation {
pub display_name: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub location_id: Option<String>,
pub metadata: Option<HashMap<String, Value>>,
pub name: Option<String>,
}Expand description
A resource that represents a Google Cloud location.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations get projects (response)
Fields
display_name: Option<String>The friendly name for this location, typically a nearby city name. For example, “Tokyo”.
labels: Option<HashMap<String, String>>Cross-service attributes for the location. For example {“cloud.googleapis.com/region”: “us-east1”}
location_id: Option<String>The canonical id for this location. For example: "us-east1".
metadata: Option<HashMap<String, Value>>Service-specific metadata. For example the available capacity at the given location.
name: Option<String>Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1"