pub struct ApigatewaySetIamPolicyRequest {
pub policy: Option<ApigatewayPolicy>,
pub update_mask: Option<FieldMask>,
}Expand description
Request message for SetIamPolicy method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations apis configs set iam policy projects (request)
- locations apis set iam policy projects (request)
- locations gateways set iam policy projects (request)
Fields
policy: Option<ApigatewayPolicy>REQUIRED: The complete policy to be applied to the resource. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Google Cloud services (such as Projects) might reject them.
update_mask: Option<FieldMask>OPTIONAL: A FieldMask specifying which fields of the policy to modify. Only the fields in the mask will be modified. If no mask is provided, the following default mask is used: paths: "bindings, etag"