pub struct ApigatewayTestIamPermissionsResponse {
pub permissions: Option<Vec<String>>,
}Expand description
Response message for TestIamPermissions method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
permissions: Option<Vec<String>>A subset of TestPermissionsRequest.permissions that the caller is allowed.